@@ -4,6 +4,14 @@
 # --------------------------------------------------
 # ##################################################
 
+# This apply() operates on a MARGIN/ICTXT agreement, converting
+# between data distributions as necessary.  This data movement
+# is inarguably an inefficiency, but at present, it is the 
+# best solution I can think of to preserve high level syntax
+# on these data structures.
+
+# Agreement occurs for ICTXT=1/MARGIN=2 and ICTXT=2/MARGIN=1
+
 setMethod("apply", signature(X="ddmatrix"),
   function(X, MARGIN, FUN, ..., reduce=FALSE, proc.dest="all")
   {
@@ -16,12 +24,12 @@ setMethod("apply", signature(X="ddmatrix"),
     oldCTXT <- X@ICTXT
     oldbldim <- X@bldim
     
-    # comparing MARGIN/context, reblocking as needed
-      # agreement occurs for ICTXT=1/MARGIN=2, and vice versa,
     # Row margin
     if (MARGIN==1){
-      if (X@ICTXT!=2)
-        X <- dmat.reblock(dx=X, bldim=X@bldim/2, ICTXT=2)
+      if (X@ICTXT!=2){
+        fudge <- max(floor(X@bldim/base.blacs(X@ICTXT)$NPCOLS), 1)
+        X <- dmat.reblock(dx=X, bldim=fudge, ICTXT=2)
+      }
       
       tmp <- apply(X@Data, MARGIN=1, FUN=FUN)
       
@@ -45,6 +53,7 @@ setMethod("apply", signature(X="ddmatrix"),
     # Column margin
     else if (MARGIN==2){
       if (X@ICTXT!=1)
+        fudge <- max(floor(X@bldim/base.blacs(X@ICTXT)$NPROWS), 1)
         X <- dmat.reblock(dx=X, bldim=X@bldim/2, ICTXT=1)
       
       tmp <- apply(X@Data, MARGIN=2, FUN=FUN)
@@ -68,13 +77,13 @@ setMethod("apply", signature(X="ddmatrix"),
   
   if (reduce==TRUE){
     if (MARGIN==1)
-      if (X@dim[2]==1)
+      if (X@dim[2L]==1)
         X <- as.vector(X, proc.dest=proc.dest)
       else
         X <- as.matrix(X, proc.dest=proc.dest)
       
     if (MARGIN==2)
-      if (X@dim[1]==1)
+      if (X@dim[1L]==1)
         X <- as.vector(X, proc.dest=proc.dest)
       else
         X <- as.matrix(X, proc.dest=proc.dest)
@@ -91,6 +100,3 @@ setMethod("apply", signature(X="ddmatrix"),
     return(X)
   }
 )
-
-
-
